diff src/share/vm/graal/graalJavaAccess.cpp @ 2891:75a99b4f1c98

Rebranded C++ part from C1X to Graal.
author Thomas Wuerthinger <thomas@wuerthinger.net>
date Wed, 08 Jun 2011 14:01:51 +0200
parents c23d45daff9b
children 0e3ec0a4eda4
line wrap: on
line diff
--- a/src/share/vm/graal/graalJavaAccess.cpp	Wed Jun 08 13:40:25 2011 +0200
+++ b/src/share/vm/graal/graalJavaAccess.cpp	Wed Jun 08 14:01:51 2011 +0200
@@ -22,7 +22,7 @@
  */
 
 #include "precompiled.hpp"
-#include "c1x/c1x_JavaAccess.hpp"
+#include "graal/graalJavaAccess.hpp"
 #include "runtime/jniHandles.hpp"
 #include "classfile/symbolTable.hpp"
 // This function is similar to javaClasses.cpp, it computes the field offset of a (static or instance) field.
@@ -50,7 +50,7 @@
   dest_offset = fd.offset();
 }
 
 // This piece of macro magic creates the contents of the c1x_compute_offsets method that initializes the field indices of all the access classes.
 
 #define START_CLASS(name) { klassOop k = SystemDictionary::name##_klass(); assert(k != NULL, "Could not find class " #name "");
 
@@ -65,7 +65,7 @@
 #define STATIC_OOP_FIELD(klass, name, signature) FIELD(klass, name, signature, true)
 
 
-void c1x_compute_offsets() {
+void graal_compute_offsets() {
   COMPILER_CLASSES_DO(START_CLASS, END_CLASS, CHAR_FIELD, INT_FIELD, BOOLEAN_FIELD, LONG_FIELD, OOP_FIELD, STATIC_OOP_FIELD)
 }
@@ -50,7 +50,7 @@
 }
 
-// This piece of macro magic creates the contents of the c1x_compute_offsets method that initializes the field indices of all the access classes.
+// This piece of macro magic creates the contents of the graal_compute_offsets method that initializes the field indices of all the access classes.
 
 #define START_CLASS(name) { klassOop k = SystemDictionary::name##_klass(); assert(k != NULL, "Could not find class " #name "");